@@ -146,6 +146,7 @@ class ErrorCodes:
     REMOTEFILECOULDNOTBEOPENED = 1361
     XRDCPERROR = 1362
     KILLPAYLOAD = 1363  # note, not a failure but a kill instruction from Raythena
+    MISSINGCREDENTIALS = 1364
 
     _error_messages = {
         GENERALERROR: "General pilot error, consult batch log",
@@ -270,7 +271,8 @@ class ErrorCodes:
         IMAGENOTFOUND: "Image not found",
         REMOTEFILECOULDNOTBEOPENED: "Remote file could not be opened",
         XRDCPERROR: "Xrdcp was unable to open file",
-        KILLPAYLOAD: "Raythena has decided to kill payload"
+        KILLPAYLOAD: "Raythena has decided to kill payload",
+        MISSINGCREDENTIALS: "Unable to locate credentials for S3 transfer"
     }
 
     put_error_codes = [1135, 1136, 1137, 1141, 1152, 1181]
