@@ -282,6 +282,11 @@ def verify_looping_job(current_time, mt, job):
     :return: exit code (int), error diagnostics (string).
     """
 
+    # only perform looping job check if desired
+    if not job.looping_check:
+        logger.debug('looping check not desired')
+        return 0, ""
+
     looping_verification_time = convert_to_int(config.Pilot.looping_verification_time, default=600)
     if current_time - mt.get('ct_looping') > looping_verification_time:
         # is the job looping?
